@@ -15,20 +15,49 @@
 
 ident = "$Id$"
 
+import copy
 import sys
 import types
-import httplib
-import urllib
+import string
+import six
+
 import socket
 import weakref
 from os.path import isfile
-from string import join, strip, split
-from UserDict import UserDict
-from cStringIO import StringIO
-from TimeoutSocket import TimeoutSocket, TimeoutError
-from urlparse import urlparse
-from httplib import HTTPConnection, HTTPSConnection
-from exceptions import Exception
+import urllib
+try:
+    from urlparse import urljoin as basejoin
+except:
+    from urllib.parse import urljoin as basejoin
+
+try:
+    from UserDict import UserDict
+    from UserDict import DictMixin
+except ImportError:
+    from collections import UserDict
+    from collections import MutableMapping as DictMixin
+
+from .TimeoutSocket import TimeoutSocket, TimeoutError
+
+try:
+    from io import StringIO
+except ImportError:
+    from cStringIO import StringIO
+
+try:
+    from urlparse import urlparse
+except ImportError:
+    from urllib.parse import urlparse
+
+try:
+    from httplib import HTTPConnection, HTTPSConnection
+except ImportError:
+    from http.client import HTTPConnection, HTTPSConnection
+
+try:
+    from exceptions import Exception
+except:
+    pass
 try:
     from ZSI import _get_idstr
 except:
@@ -45,9 +74,10 @@ import xml.dom.minidom
 from xml.dom import Node
 
 import logging
-from c14n import Canonicalize
-from Namespaces import SCHEMA, SOAP, XMLNS, ZSI_SCHEMA_URI
+from .c14n import Canonicalize
+from .Namespaces import SCHEMA, SOAP, XMLNS, ZSI_SCHEMA_URI
 
+DEFAULT = "".join
 
 try:
     from xml.dom.ext import SplitQName
@@ -75,44 +105,37 @@ except:
             return
         return tuple(l)
 
-#
-# python2.3 urllib.basejoin does not remove current directory ./
-# from path and this causes problems on subsequent basejoins.
-#
-basejoin = urllib.basejoin
-if sys.version_info[0:2] < (2, 4, 0, 'final', 0)[0:2]:
-    #basejoin = lambda base,url: urllib.basejoin(base,url.lstrip('./'))
-    token = './'
-
-    def basejoin(base, url):
-        if url.startswith(token) is True:
-            return urllib.basejoin(base, url[2:])
-        return urllib.basejoin(base, url)
-
 
 class NamespaceError(Exception):
+
     """Used to indicate a Namespace Error."""
 
 
 class RecursionError(Exception):
+
     """Used to indicate a HTTP redirect recursion."""
 
 
 class ParseError(Exception):
+
     """Used to indicate a XML parsing error."""
 
 
 class DOMException(Exception):
+
     """Used to indicate a problem processing DOM."""
 
 
 class Base:
+
     """Base class for instance level Logging"""
-    def __init__(self, module=__name__):
-        self.logger = logging.getLogger('%s-%s(%s)' % (module, self.__class__, _get_idstr(self)))
+
+    def __init__(self, logger=None):
+        self.logger = logger or logging.getLogger(__name__)
 
 
 class HTTPResponse:
+
     """Captures the information in an HTTP response message."""
 
     def __init__(self, response):
@@ -124,7 +147,9 @@ class HTTPResponse:
 
 
 class TimeoutHTTP(HTTPConnection):
+
     """A custom http connection object that supports socket timeout."""
+
     def __init__(self, host, port=None, timeout=20):
         HTTPConnection.__init__(self, host, port)
         self.timeout = timeout
@@ -135,12 +160,14 @@ class TimeoutHTTP(HTTPConnection):
 
 
 class TimeoutHTTPS(HTTPSConnection):
+
     """A custom https object that supports socket timeout. Note that this
        is not really complete. The builtin SSL support in the Python socket
        module requires a real socket (type) to be passed in to be hooked to
        SSL. That means our fake socket won't work and our timeout hacks are
        bypassed for send and recv calls. Since our hack _is_ in place at
        connect() time, it should at least provide some timeout protection."""
+
     def __init__(self, host, port=None, timeout=20, **kwargs):
         HTTPSConnection.__init__(self, str(host), port, **kwargs)
         self.timeout = timeout
@@ -208,7 +235,7 @@ def urlopen(url, timeout=20, redirects=None):
             if redirects is not None and location in redirects:
                 raise RecursionError(
                     'Circular HTTP redirection detected.'
-                    )
+                )
             if redirects is None:
                 redirects = {}
             redirects[location] = 1
@@ -224,15 +251,16 @@ def urlopen(url, timeout=20, redirects=None):
 
 
 class DOM:
+
     """The DOM singleton defines a number of XML related constants and
        provides a number of utility methods for DOM related tasks. It
        also provides some basic abstractions so that the rest of the
        package need not care about actual DOM implementation in use."""
 
-    looseNamespaces = False  # if can't find a referenced namespace, try the default one
+    # if can't find a referenced namespace, try the default one
+    looseNamespaces = False
 
     # Namespace stuff related to the SOAP specification.
-
     NS_SOAP_ENV_1_1 = 'http://schemas.xmlsoap.org/soap/envelope/'
     NS_SOAP_ENC_1_1 = 'http://schemas.xmlsoap.org/soap/encoding/'
 
@@ -261,40 +289,40 @@ class DOM:
             return value
         raise ValueError(
             'Unsupported SOAP envelope uri: %s' % uri
-            )
+        )
 
     def GetSOAPEnvUri(self, version):
         """Return the appropriate SOAP envelope uri for a given
            human-friendly SOAP version string (e.g. '1.1')."""
-        attrname = 'NS_SOAP_ENV_%s' % join(split(version, '.'), '_')
+        attrname = 'NS_SOAP_ENV_%s' % '_'.join(version.split('.'))
         value = getattr(self, attrname, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported SOAP version: %s' % version
-            )
+        )
 
     def GetSOAPEncUri(self, version):
         """Return the appropriate SOAP encoding uri for a given
            human-friendly SOAP version string (e.g. '1.1')."""
-        attrname = 'NS_SOAP_ENC_%s' % join(split(version, '.'), '_')
+        attrname = 'NS_SOAP_ENC_%s' % '_'.join(version.split('.'))
         value = getattr(self, attrname, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported SOAP version: %s' % version
-            )
+        )
 
     def GetSOAPActorNextUri(self, version):
         """Return the right special next-actor uri for a given
            human-friendly SOAP version string (e.g. '1.1')."""
-        attrname = 'SOAP_ACTOR_NEXT_%s' % join(split(version, '.'), '_')
+        attrname = 'SOAP_ACTOR_NEXT_%s' % '_'.join(version.split('.'))
         value = getattr(self, attrname, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported SOAP version: %s' % version
-            )
+        )
 
     # Namespace stuff related to XML Schema.
     NS_XSD_99 = 'http://www.w3.org/1999/XMLSchema'
@@ -318,7 +346,7 @@ class DOM:
         NS_XSD_01: NS_XSI_01,
     }
 
-    for key, value in _xsd_uri_mapping.items():
+    for key, value in copy.deepcopy(_xsd_uri_mapping).items():
         _xsd_uri_mapping[value] = key
 
     def InstanceUriForSchemaUri(self, uri):
@@ -363,52 +391,52 @@ class DOM:
             return value
         raise ValueError(
             'Unsupported SOAP envelope uri: %s' % uri
-            )
+        )
 
     def GetWSDLUri(self, version):
-        attr = 'NS_WSDL_%s' % join(split(version, '.'), '_')
+        attr = 'NS_WSDL_%s' % '_'.join(version.split('.'))
         value = getattr(self, attr, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported WSDL version: %s' % version
-            )
+        )
 
     def GetWSDLSoapBindingUri(self, version):
-        attr = 'NS_SOAP_BINDING_%s' % join(split(version, '.'), '_')
+        attr = 'NS_SOAP_BINDING_%s' % '_'.join(version.split('.'))
         value = getattr(self, attr, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported WSDL version: %s' % version
-            )
+        )
 
     def GetWSDLHttpBindingUri(self, version):
-        attr = 'NS_HTTP_BINDING_%s' % join(split(version, '.'), '_')
+        attr = 'NS_HTTP_BINDING_%s' % '_'.join(version.split('.'))
         value = getattr(self, attr, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported WSDL version: %s' % version
-            )
+        )
 
     def GetWSDLMimeBindingUri(self, version):
-        attr = 'NS_MIME_BINDING_%s' % join(split(version, '.'), '_')
+        attr = 'NS_MIME_BINDING_%s' % '_'.join(version.split('.'))
         value = getattr(self, attr, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported WSDL version: %s' % version
-            )
+        )
 
     def GetWSDLHttpTransportUri(self, version):
-        attr = 'NS_SOAP_HTTP_%s' % join(split(version, '.'), '_')
+        attr = 'NS_SOAP_HTTP_%s' % '_'.join(version.split('.'))
         value = getattr(self, attr, None)
         if value is not None:
             return value
         raise ValueError(
             'Unsupported WSDL version: %s' % version
-            )
+        )
 
     # Other xml namespace constants.
     NS_XMLNS = 'http://www.w3.org/2000/xmlns/'
@@ -419,9 +447,9 @@ class DOM:
         if node.nodeType != node.ELEMENT_NODE:
             return 0
         return node.localName == name and \
-               (nsuri is None or self.nsUriMatch(node.namespaceURI, nsuri))
+            (nsuri is None or self.nsUriMatch(node.namespaceURI, nsuri))
 
-    def getElement(self, node, name, nsuri=None, default=join):
+    def getElement(self, node, name, nsuri=None, default=DEFAULT):
         """Return the first child of node with a matching name and
            namespace uri, or the default if one is provided."""
         nsmatch = self.nsUriMatch
@@ -429,14 +457,13 @@ class DOM:
         for child in node.childNodes:
             if child.nodeType == ELEMENT_NODE:
                 if ((child.localName == name or name is None) and
-                    (nsuri is None or nsmatch(child.namespaceURI, nsuri))
-                    ):
+                        (nsuri is None or nsmatch(child.namespaceURI, nsuri))):
                     return child
-        if default is not join:
+        if default != DEFAULT:
             return default
         raise KeyError(name)
 
-    def getElementById(self, node, id, default=join):
+    def getElementById(self, node, id, default=DEFAULT):
         """Return the first child of node matching an id reference."""
         attrget = self.getAttr
         ELEMENT_NODE = node.ELEMENT_NODE
@@ -444,7 +471,7 @@ class DOM:
             if child.nodeType == ELEMENT_NODE:
                 if attrget(child, 'id') == id:
                     return child
-        if default is not join:
+        if default != DEFAULT:
             return default
         raise KeyError(name)
 
@@ -476,7 +503,7 @@ class DOM:
         for child in node.childNodes:
             if child.nodeType == ELEMENT_NODE:
                 if ((child.localName == name or name is None) and (
-                    (nsuri is None) or nsmatch(child.namespaceURI, nsuri))):
+                        (nsuri is None) or nsmatch(child.namespaceURI, nsuri))):
                     result.append(child)
         return result
 
@@ -490,23 +517,35 @@ class DOM:
             return False
         return node.hasAttributeNS(nsuri, name)
 
-    def getAttr(self, node, name, nsuri=None, default=join):
+    def getAttr(self, node, name, nsuri=None, default=DEFAULT):
         """Return the value of the attribute named 'name' with the
            optional nsuri, or the default if one is specified. If
            nsuri is not specified, an attribute that matches the
            given name will be returned regardless of namespace."""
         if nsuri is None:
-            result = node._attrs.get(name, None)
+            if node._attrs is None:
+                result = None
+            else:
+                result = node._attrs.get(name, None)
             if result is None:
-                for item in node._attrsNS.keys():
-                    if item[1] == name:
-                        result = node._attrsNS[item]
-                        break
+                if node._attrsNS is None:
+                    result = None
+                else:
+                    for item in node._attrsNS.keys():
+                        if item[1] == name:
+                            result = node._attrsNS[item]
+                            break
         else:
-            result = node._attrsNS.get((nsuri, name), None)
+            if node._attrsNS is None:
+                result = None
+            else:
+                if node._attrsNS is None:
+                    result = None
+                else:
+                    result = node._attrsNS.get((nsuri, name), None)
         if result is not None:
             return result.value
-        if default is not join:
+        if default != DEFAULT:
             return default
         return ''
 
@@ -528,9 +567,9 @@ class DOM:
             if nodetype == child.TEXT_NODE or \
                nodetype == child.CDATA_SECTION_NODE:
                 result.append(child.nodeValue)
-        value = join(result, '')
+        value = ''.join(result)
         if preserve_ws is None:
-            value = strip(value)
+            value = value.strip()
         return value
 
     def findNamespaceURI(self, prefix, node):
@@ -555,7 +594,8 @@ class DOM:
                 if DOM.looseNamespaces:
                     return self.findTargetNS(orig_node)
                 else:
-                    raise DOMException('Value for prefix %s not found.' % prefix)
+                    raise DOMException('Value for prefix %s not found.'
+                                       % prefix)
 
     def findDefaultNS(self, node):
         """Return the current default namespace uri for the given node."""
@@ -653,7 +693,7 @@ class DOM:
 
         try:
             result = self.loadDocument(file)
-        except Exception, ex:
+        except Exception as ex:
             file.close()
             raise ParseError(('Failed to load document %s' % url,) + ex.args)
         else:
@@ -664,9 +704,11 @@ DOM = DOM()
 
 
 class MessageInterface:
+
     '''Higher Level Interface, delegates to DOM singleton, must
     be subclassed and implement all methods that throw NotImplementedError.
     '''
+
     def __init__(self, sw):
         '''Constructor, May be extended, do not override.
             sw -- soapWriter instance
@@ -725,8 +767,7 @@ class MessageInterface:
 
 
 class ElementProxy(Base, MessageInterface):
-    '''
-    '''
+
     _soap_env_prefix = 'SOAP-ENV'
     _soap_enc_prefix = 'SOAP-ENC'
     _zsi_prefix = 'ZSI'
@@ -743,11 +784,11 @@ class ElementProxy(Base, MessageInterface):
     _xml_nsuri = XMLNS.XML
     _xmlns_nsuri = XMLNS.BASE
 
-    standard_ns = {\
+    standard_ns = {
         _xml_prefix: _xml_nsuri,
         _xmlns_prefix: _xmlns_nsuri
     }
-    reserved_ns = {\
+    reserved_ns = {
         _soap_env_prefix: _soap_env_nsuri,
         _soap_enc_prefix: _soap_enc_nsuri,
         _zsi_prefix: _zsi_nsuri,
@@ -783,9 +824,11 @@ class ElementProxy(Base, MessageInterface):
         '''
         from Ft.Xml import XPath
         if not processorNss:
-            context = XPath.Context.Context(self.node, processorNss=self.processorNss)
+            context = XPath.Context.Context(self.node,
+                                            processorNss=self.processorNss)
         else:
-            context = XPath.Context.Context(self.node, processorNss=processorNss)
+            context = XPath.Context.Context(self.node,
+                                            processorNss=processorNss)
         nodes = expression.evaluate(context)
         return map(lambda node: ElementProxy(self.sw, node), nodes)
 
@@ -804,7 +847,8 @@ class ElementProxy(Base, MessageInterface):
         if localName and self.node:
             check = self._dom.isElement(self.node, localName, namespaceURI)
         if not check:
-            raise NamespaceError('unexpected node type %s, expecting %s' % (self.node, localName))
+            raise NamespaceError('unexpected node type %s, expecting %s'
+                                 % (self.node, localName))
 
     def setNode(self, node=None):
         if node:
@@ -813,13 +857,15 @@ class ElementProxy(Base, MessageInterface):
             else:
                 self.node = node
         elif self.node:
-            node = self._dom.getElement(self.node, self.name, self.namespaceURI, default=None)
+            node = self._dom.getElement(self.node, self.name,
+                                        self.namespaceURI, default=None)
             if not node:
-                raise NamespaceError('cant find element (%s, %s)' % (self.namespaceURI, self.name))
+                raise NamespaceError('cant find element (%s, %s)' %
+                                     (self.namespaceURI, self.name))
             self.node = node
         else:
-            #self.node = self._dom.create(self.node, self.name, self.namespaceURI, default=None)
-            self.createDocument(self.namespaceURI, localName=self.name, doctype=None)
+            self.createDocument(self.namespaceURI, localName=self.name,
+                                doctype=None)
 
         self.checkNode()
 
@@ -845,7 +891,7 @@ class ElementProxy(Base, MessageInterface):
             prefix = 'ns%d' % self._indx
             try:
                 self._dom.findNamespaceURI(prefix, self._getNode())
-            except DOMException, ex:
+            except DOMException as ex:
                 break
         return prefix
 
@@ -857,9 +903,9 @@ class ElementProxy(Base, MessageInterface):
         '''
         try:
             if node and (node.nodeType == node.ELEMENT_NODE) and \
-                (nsuri == self._dom.findDefaultNS(node)):
+                    (nsuri == self._dom.findDefaultNS(node)):
                 return None
-        except DOMException, ex:
+        except DOMException as ex:
             pass
         if nsuri == XMLNS.XML:
             return self._xml_prefix
@@ -867,7 +913,7 @@ class ElementProxy(Base, MessageInterface):
             for attr in node.attributes.values():
                 if attr.namespaceURI == XMLNS.BASE \
                    and nsuri == attr.value:
-                        return attr.localName
+                    return attr.localName
             else:
                 if node.parentNode:
                     return self._getPrefix(node.parentNode, nsuri)
@@ -910,7 +956,7 @@ class ElementProxy(Base, MessageInterface):
     def getPrefix(self, namespaceURI):
         try:
             prefix = self._getPrefix(node=self.node, nsuri=namespaceURI)
-        except NamespaceError, ex:
+        except NamespaceError as ex:
             prefix = self._getUniquePrefix()
             self.setNamespaceAttribute(prefix, namespaceURI)
         return prefix
@@ -942,7 +988,8 @@ class ElementProxy(Base, MessageInterface):
         return self.canonicalize()
 
     def createDocument(self, namespaceURI, localName, doctype=None):
-        '''If specified must be a SOAP envelope, else may contruct an empty document.
+        '''If specified must be a SOAP envelope, else may contruct an empty
+        document.
         '''
         prefix = self._soap_env_prefix
 
@@ -952,22 +999,27 @@ class ElementProxy(Base, MessageInterface):
             self.node = self._dom.createDocument(None, None, None)
             return
         else:
-            raise KeyError('only support creation of document in %s' % self.reserved_ns[prefix])
+            raise KeyError('only support creation of document in %s' %
+                           self.reserved_ns[prefix])
 
-        document = self._dom.createDocument(nsuri=namespaceURI, qname=qualifiedName, doctype=doctype)
+        document = self._dom.createDocument(nsuri=namespaceURI,
+                                            qname=qualifiedName,
+                                            doctype=doctype)
         self.node = document.childNodes[0]
 
         #set up reserved namespace attributes
         for prefix, nsuri in self.reserved_ns.items():
             self._setAttributeNS(namespaceURI=self._xmlns_nsuri,
-                qualifiedName='%s:%s' % (self._xmlns_prefix, prefix),
-                value=nsuri)
+                                 qualifiedName='%s:%s' % (self._xmlns_prefix,
+                                                          prefix),
+                                 value=nsuri)
 
     #############################################
     #Methods for attributes
     #############################################
     def hasAttribute(self, namespaceURI, localName):
-        return self._dom.hasAttr(self._getNode(), name=localName, nsuri=namespaceURI)
+        return self._dom.hasAttr(self._getNode(), name=localName,
+                                 nsuri=namespaceURI)
 
     def setAttributeType(self, namespaceURI, localName):
         '''set xsi:type
@@ -1001,7 +1053,7 @@ class ElementProxy(Base, MessageInterface):
         if namespaceURI:
             try:
                 prefix = self.getPrefix(namespaceURI)
-            except KeyError, ex:
+            except KeyError as ex:
                 prefix = 'ns2'
                 self.setNamespaceAttribute(prefix, namespaceURI)
         qualifiedName = localName
@@ -1074,7 +1126,8 @@ class ElementProxy(Base, MessageInterface):
         if prefix:
             qualifiedName = '%s:%s' % (prefix, localName)
         node = self.createElementNS(namespaceURI, qualifiedName)
-        self._insertBefore(newChild=node._getNode(), refChild=refChild._getNode())
+        self._insertBefore(newChild=node._getNode(),
+                           refChild=refChild._getNode())
         return node
 
     def getElement(self, namespaceURI, localName):
@@ -1083,7 +1136,8 @@ class ElementProxy(Base, MessageInterface):
             namespaceURI -- namespace of element
             localName -- local name of element
         '''
-        node = self._dom.getElement(self.node, localName, namespaceURI, default=None)
+        node = self._dom.getElement(self.node, localName, namespaceURI,
+                                    default=None)
         if node:
             return ElementProxy(self.sw, node)
         return None
@@ -1137,6 +1191,7 @@ class ElementProxy(Base, MessageInterface):
 
 
 class Collection(UserDict):
+
     """Helper class for maintaining ordered named collections."""
     default = lambda self, k: k.name
 
@@ -1147,7 +1202,8 @@ class Collection(UserDict):
         self._func = key or self.default
 
     def __getitem__(self, key):
-        NumberTypes = (types.IntType, types.LongType, types.FloatType, types.ComplexType)
+        NumberTypes = six.integer_types
+        NumberTypes = NumberTypes + (type(float), type(complex))
         if isinstance(key, NumberTypes):
             return self.list[key]
         return self.data[key]
@@ -1168,7 +1224,9 @@ class Collection(UserDict):
 
 
 class CollectionNS(UserDict):
+
     """Helper class for maintaining ordered named collections."""
+
     default = lambda self, k: k.name
 
     def __init__(self, parent, key=None):
@@ -1180,7 +1238,7 @@ class CollectionNS(UserDict):
 
     def __getitem__(self, key):
         self.targetNamespace = self.parent().targetNamespace
-        if isinstance(key, types.IntType):
+        if isinstance(key, six.integer_types):
             return self.list[key]
         elif self.__isSequence(key):
             nsuri, name = key
@@ -1190,18 +1248,21 @@ class CollectionNS(UserDict):
     def __setitem__(self, key, item):
         item.parent = weakref.ref(self)
         self.list.append(item)
-        targetNamespace = getattr(item, 'targetNamespace', self.parent().targetNamespace)
+        targetNamespace = getattr(item, 'targetNamespace',
+                                  self.parent().targetNamespace)
         if not targetNamespace in self.data:
             self.data[targetNamespace] = {}
         self.data[targetNamespace][key] = item
 
     def __isSequence(self, key):
-        return (type(key) in (types.TupleType, types.ListType) and len(key) == 2)
+        return (isinstance(key, (tuple, list))
+                and len(key) == 2)
 
     def keys(self):
         keys = []
         for tns in self.data.keys():
-            keys.append(map(lambda i: (tns, self._func(i)), self.data[tns].values()))
+            keys.append(map(lambda i: (tns, self._func(i)),
+                            self.data[tns].values()))
         return keys
 
     def items(self):
@@ -1294,8 +1355,10 @@ if 1:
 # prefixed attribute names during cloning.
 #
 # key (attr.namespaceURI, tag)
-# ('http://www.w3.org/2000/xmlns/', u'xsd')   <xml.dom.minidom.Attr instance at 0x82227c4>
-# ('http://www.w3.org/2000/xmlns/', 'xmlns')   <xml.dom.minidom.Attr instance at 0x8414b3c>
+# ('http://www.w3.org/2000/xmlns/', u'xsd')
+#                <xml.dom.minidom.Attr instance at 0x82227c4>
+# ('http://www.w3.org/2000/xmlns/', 'xmlns')
+#                <xml.dom.minidom.Attr instance at 0x8414b3c>
 #
 # xml.dom.minidom.Attr.nodeName = xmlns:xsd
 # xml.dom.minidom.Attr.value =  = http://www.w3.org/2001/XMLSchema
@@ -1314,7 +1377,8 @@ if 1:
             clone = newOwnerDocument.createElementNS(node.namespaceURI,
                                                      node.nodeName)
             for attr in node.attributes.values():
-                clone.setAttributeNS(attr.namespaceURI, attr.nodeName, attr.value)
+                clone.setAttributeNS(attr.namespaceURI, attr.nodeName,
+                                     attr.value)
 
                 prefix, tag = xml.dom.minidom._nssplit(attr.nodeName)
                 if prefix == 'xmlns':
@@ -1322,18 +1386,21 @@ if 1:
                 elif prefix:
                     a = clone.getAttributeNodeNS(attr.namespaceURI, tag)
                 else:
-                    a = clone.getAttributeNodeNS(attr.namespaceURI, attr.nodeName)
+                    a = clone.getAttributeNodeNS(attr.namespaceURI,
+                                                 attr.nodeName)
                 a.specified = attr.specified
 
             if deep:
                 for child in node.childNodes:
-                    c = xml.dom.minidom._clone_node(child, deep, newOwnerDocument)
+                    c = xml.dom.minidom._clone_node(child, deep,
+                                                    newOwnerDocument)
                     clone.appendChild(c)
         elif node.nodeType == xml.dom.minidom.Node.DOCUMENT_FRAGMENT_NODE:
             clone = newOwnerDocument.createDocumentFragment()
             if deep:
                 for child in node.childNodes:
-                    c = xml.dom.minidom._clone_node(child, deep, newOwnerDocument)
+                    c = xml.dom.minidom._clone_node(child, deep,
+                                                    newOwnerDocument)
                     clone.appendChild(c)
 
         elif node.nodeType == xml.dom.minidom.Node.TEXT_NODE:
@@ -1360,14 +1427,16 @@ if 1:
                 clone.entities._seq = []
                 clone.notations._seq = []
                 for n in node.notations._seq:
-                    notation = xml.dom.minidom.Notation(n.nodeName, n.publicId, n.systemId)
+                    notation = xml.dom.minidom.Notation(n.nodeName, n.publicId,
+                                                        n.systemId)
                     notation.ownerDocument = newOwnerDocument
                     clone.notations._seq.append(notation)
                     if hasattr(n, '_call_user_data_handler'):
                         n._call_user_data_handler(operation, n, notation)
                 for e in node.entities._seq:
-                    entity = xml.dom.minidom.Entity(e.nodeName, e.publicId, e.systemId,
-                                    e.notationName)
+                    entity = xml.dom.minidom.Entity(e.nodeName, e.publicId,
+                                                    e.systemId,
+                                                    e.notationName)
                     entity.actualEncoding = e.actualEncoding
                     entity.encoding = e.encoding
                     entity.version = e.version
